@@ -2,18 +2,18 @@ import datetime
 import os
 import sys
 import time
-from typing import Any
+from typing import Any, Optional
 
 from . import (getAllFileList, getFileBaseName, getPath, hold, makeFolder,
                readFile, remove, writeFile)
-
-from .log import error, info, initLogger, warning, getCountCritical, getCountError, getCountWarning
+from .log import (error, getCountCritical, getCountError, getCountWarning,
+                  info, initLogger, warning)
 from .print import (BACKGROUND_DARKGREEN, BACKGROUND_DARKPINK,
                     BACKGROUND_DARKRED, BACKGROUND_DARKYELLOW,
                     FOREGROUND_BLACK, FOREGROUND_DARKRED, FOREGROUND_WHITE,
                     resetPrintColor, setPrintColor)
 
-TaskDataType = tuple[str, dict[str, Any]]
+TaskDataType = tuple[str, Optional[dict[str, Any]]]
 
 _workspacePath: str = ""
 
@@ -112,8 +112,13 @@ def _runTaskList(taskList: list[TaskDataType]):
             remove(logFile)
         logFile = getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
         initLogger(logFile=logFile)
-        for moduleName, parDict in taskList:
-            runTask(moduleName, **parDict)
+        for taskItem in taskList:
+            moduleName = taskItem[0]
+            parDict = taskItem[1]
+            if parDict:
+                runTask(moduleName, **parDict)
+            else:
+                runTask(moduleName)
     except Exception:
         import traceback
         _setPrintRedColor()
